local wezterm = require 'wezterm'
local config = wezterm.config_builder()
local act = wezterm.action
local io = require 'io'
local os = require 'os'


config.enable_wayland = false;
-- config.front_end = "WebGpu";

config.font_size = 14
config.font = wezterm.font {
  family = 'JetBrains Mono',
  weight = 'Medium'
}

-- config.enable_scroll_bar = true

config.color_scheme = 'Adventure'
config.colors = {
  background = "#111111",
  tab_bar = {
    background = "#111111",
    inactive_tab = {
      fg_color = "#444444",
      bg_color = "#111111"
    }
  }
}

config.background = {
  {
    source = {
      Color = '#111111'
    },
    width = "100%",
    height = "100%",
    opacity = 1
  }
}

config.window_decorations = "RESIZE"

config.window_padding = {
  left = 12,
  right = 12,
  top = 6,
  bottom = 6,
}

config.cursor_thickness = 2
config.default_cursor_style = 'SteadyBar'
config.enable_tab_bar = false;

config.enable_kitty_keyboard = true

config.unzoom_on_switch_pane = true

config.keys = {
  {
    key = 'Enter',
    mods = 'CTRL',
    action = act.SplitVertical { domain = 'CurrentPaneDomain' },
  },
  {
    key = 'Enter',
    mods = 'CTRL|SHIFT',
    action = act.SplitHorizontal { domain = 'CurrentPaneDomain' },
  },
  {
    key = 'w',
    mods = 'CTRL',
    action = wezterm.action.CloseCurrentTab { confirm = true },
  },
  {
    key = 'w',
    mods = 'CTRL|SHIFT',
    action = act.DetachDomain 'CurrentPaneDomain',
  },
  {
    key = 'k',
    mods = 'CTRL|SHIFT',
    action = act.Multiple {
      act.ClearScrollback 'ScrollbackAndViewport',
      act.SendKey { key = 'L', mods = 'CTRL' },
    },
  },
  {
    key = 'z',
    mods = 'CTRL|META',
    action = wezterm.action.TogglePaneZoomState,
  },
  {
    key = 'E',
    mods = 'CTRL',
    action = act.EmitEvent 'trigger-emacs-with-scrollback',
  },
  {
    key = 'o',
    mods = 'CTRL',
    action = wezterm.action.ShowLauncher
  },

  { key="Backspace", mods="CTRL", action=act.SendKey { key="Backspace", mods="META" } },

  { key='t', mods='CTRL', action=act { SpawnCommandInNewTab = { cwd = wezterm.home_dir } } },

  { key="LeftArrow",  mods="CTRL|META", action=act.ActivateTabRelative(-1) },
  { key="RightArrow",  mods="CTRL|META", action=act.ActivateTabRelative(1) },

  { key="UpArrow",  mods="CTRL|META", action=act.ActivatePaneDirection("Prev") },
  { key="DownArrow",  mods="CTRL|META", action=act.ActivatePaneDirection("Next") },

  { key='h', mods='CTRL|META', action=wezterm.action{ActivatePaneDirection="Left"} },
  { key='l', mods='CTRL|META', action=wezterm.action{ActivatePaneDirection="Right"} },
  { key='j', mods='CTRL|META', action=wezterm.action{ActivatePaneDirection="Up"} },
  { key='k', mods='CTRL|META', action=wezterm.action{ActivatePaneDirection="Down"} },
}

return config
